==> config-1.4.0-sources.jar: org/opennms/integration/api/xml/schema/eventconf/EventLabelComparator.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2013-2014 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2014 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.integration.api.xml.schema.eventconf;

import java.io.Serializable;
import java.util.Comparator;

public class EventLabelComparator implements Comparator<Event>, Serializable {
    private static final long serialVersionUID = 7976730920523203921L;

    @Override
    public int compare(final Event e1, final Event e2) {
        if (e1.getEventLabel() == e2.getEventLabel()) return 0;
        if (e1.getEventLabel() == null) return -1;
        if (e2.getEventLabel() == null) return 1;
        return e1.getEventLabel().compareToIgnoreCase(e2.getEventLabel());
    }
}

==> config-1.6.1-sources.jar: org/opennms/integration/api/xml/schema/eventconf/EventLabelComparator.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2013-2023 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2023 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.integration.api.xml.schema.eventconf;

import java.io.Serializable;
import java.util.Comparator;

public class EventLabelComparator implements Comparator<Event>, Serializable {
    private static final long serialVersionUID = 1L;

    @Override
    public int compare(final Event e1, final Event e2) {
        final var e1label = e1 == null? null : e1.getEventLabel();
        final var e2label = e2 == null? null : e2.getEventLabel();
        if (e1label == null && e2label == null) return 0;
        if (e1label == null) return -1;
        if (e2label == null) return 1;
        if (e1label.equals(e2label)) return 0;
        return e1label.compareToIgnoreCase(e2label);
    }
}
